==> rhdm-7.5.0-sources.zip: rhba-7.5.0.GA-src/org.jboss.brms-bpmsuite.patching-patching-tools-parent-7.5.0/client-patcher/src/main/java/org/jboss/brmsbpmsuite/patching/client/VersionCheckerProvider.java <==
package org.jboss.brmsbpmsuite.patching.client;

import org.osgi.framework.Version;

import java.io.IOException;
import java.util.Properties;

public class VersionCheckerProvider implements VersionChecker {
    private final Version finalRelease;
    private final Version finalPatch;

    private VersionCheckerProvider(Version finalRelease, Version finalPatch) {
        validate(finalRelease, finalPatch);
        this.finalRelease = finalRelease;
        this.finalPatch = finalPatch;
    }

    private void validate(Version finalRelease, Version finalPatch) {
        if (!isFinal(finalRelease)) {
            throw new InvalidVersionException("final-release is not a valid version!");
        }
        if (!isFinal(finalPatch)) {
            throw new InvalidVersionException("final-patch is not a valid community version!");
        }
    }

    private boolean isFinal(Version version) {
        return version.getQualifier().toLowerCase().startsWith("final");
    }

    public boolean isValidForVersion(Version version) {
        return isFinal(version) &&
                version.compareTo(finalRelease) >= 0
                && version.compareTo(finalPatch) < 0;
    }

    public static VersionChecker getInstance() {
        Properties versionProperties = new Properties();
        try {
            versionProperties.load(ClassLoader.getSystemResourceAsStream("version.properties"));
        } catch (IOException e) {
            throw new InvalidVersionException("Couldn't find the applicable version definitions!");
        }

        return createInstance(versionProperties);
    }

    static VersionChecker createInstance(Properties versionProperties) {
        Version finalRelease = versionFromProperties(versionProperties, "final-release");
        Version finalPatch = versionFromProperties(versionProperties, "final-patch");
        return new VersionCheckerProvider(finalRelease, finalPatch);
    }

    static Version versionFromProperties(Properties versionProperties, String versionName) {
        if (versionProperties.containsKey(versionName)) {
            return Version.parseVersion(versionProperties.getProperty(versionName));
        }
        throw new InvalidVersionException("The property to create the '" + versionName + "' version doesn't exist!");
    }

}

==> rhdm-7.8.0-sources.zip: rhba-7.8.0.GA-src/org.jboss.brms-bpmsuite.patching-patching-tools-parent-7.8.0/client-patcher/src/main/java/org/jboss/brmsbpmsuite/patching/client/VersionCheckerProvider.java <==
package org.jboss.brmsbpmsuite.patching.client;

import org.osgi.framework.Version;

import java.io.IOException;
import java.util.Properties;

public class VersionCheckerProvider implements VersionChecker {
    private final Version finalRelease;
    private final Version finalPatch;

    private VersionCheckerProvider(Version finalRelease, Version finalPatch) {
        validate(finalRelease, finalPatch);
        this.finalRelease = finalRelease;
        this.finalPatch = finalPatch;
    }

    private void validate(Version finalRelease, Version finalPatch) {
        if (!isFinal(finalRelease)) {
            throw new InvalidVersionException("version.community.min is not a valid version!");
        }
        if (!isFinal(finalPatch)) {
            throw new InvalidVersionException("version.community.max is not a valid community version!");
        }
    }

    private boolean isFinal(Version version) {
        return version.getQualifier().toLowerCase().startsWith("final");
    }

    public boolean isValidForVersion(Version version) {
        return isFinal(version) &&
                version.compareTo(finalRelease) >= 0
                && version.compareTo(finalPatch) < 0;
    }

    public static VersionChecker getInstance() {
        Properties versionProperties = new Properties();
        try {
            versionProperties.load(ClassLoader.getSystemResourceAsStream("version.properties"));
        } catch (IOException e) {
            throw new InvalidVersionException("Couldn't find the applicable version definitions!");
        }

        return createInstance(versionProperties);
    }

    static VersionChecker createInstance(Properties versionProperties) {
        Version finalRelease = versionFromProperties(versionProperties, "version.community.min");
        Version finalPatch = versionFromProperties(versionProperties, "version.community.max");
        return new VersionCheckerProvider(finalRelease, finalPatch);
    }

    static Version versionFromProperties(Properties versionProperties, String versionName) {
        if (versionProperties.containsKey(versionName)) {
            return Version.parseVersion(versionProperties.getProperty(versionName));
        }
        throw new InvalidVersionException("The property to create the '" + versionName + "' version doesn't exist!");
    }

}
